--[[
BossPanel - Factions
a port of Titan Panel [Factions] by Corgi
]]--

BossPanel_Factions = BossPanelPlugin:new({
	name          = BossPanel_FactionsLocals.NAME,
	description   = BossPanel_FactionsLocals.DESCRIPTION,
	version       = "0.0.4",
	releaseDate   = "03-28-2006",
	aceCompatible = 103,
	bpCompatible  = 902,
	author        = "Corgi",
	email         = "corgiwow@gmail.com",
	website       = "http://corgi.wowinterface.com",
	category      = "interface",
	db            = AceDatabase:new("BossPanel_FactionsDB"),
	defaults      = {
		showPercent = FALSE,
		monitor	  = FALSE,
	},
	cmd           = AceChatCmd:new(BossPanel_FactionsLocals.COMMANDS, BossPanel_FactionsLocals.CMD_OPTIONS),
	loc 		  = BossPanel_FactionsLocals,
	hasIcon       = TRUE,
	hasNoText	  = FALSE,
	canHideText	  = TRUE,
	
	-- Methods
	
	Enable = function(self) 
	  self:RegisterEvent("UPDATE_FACTION","Update")
	end,
   
    Initialize = function(self)
		if ( self.charData.monitor ~= nil or self.charData.monitor ~= "" ) then
			self.data.monitor = self.charData.monitor
		else
			self.data.monitor = ""
		end
		self:UpdateText()
	end,
	
	OnClick = function(self) 
      ToggleCharacter("ReputationFrame")
	end,
	
	--Update2 = function(self)
	--	self:UpdateMonitor()
	--	self:Update()
	--end,
	
	Report = function(self)
		self.cmd:report({
			{text=self.loc.ARGUMENT_PERCENT, val=(self:IsShowingPercent() and 1 or 0), map=BossPanelLocals.MAP_ONOFF},
		})
	end,
	
	MenuSettings = function(self)		
		local info = {}
		
		if ( UIDROPDOWNMENU_MENU_LEVEL == 2 ) then
			if ( UIDROPDOWNMENU_MENU_VALUE == self.loc.MENU_MONITOR ) then
				
				local NumFactions = GetNumFactions()

				local faction_name, faction_description, faction_standingID, faction_barMin, faction_barMax, faction_barValue, faction_atWarWith
				local faction_canToggleAtWar, faction_isHeader, faction_isCollapsed

				local factionIndex
				local standingText = ""
				
				for factionIndex=1, NumFactions do
			
					local tmpStanding = ""
					
					faction_name, faction_description, faction_standingID, faction_barMin, faction_barMax, faction_barValue, faction_atWarWith, faction_canToggleAtWar, faction_isHeader, faction_isCollapsed = GetFactionInfo(factionIndex)
			
					if ( not faction_isHeader ) then
					
						standingText = self:FindRep(faction_standingID)
						
						if ( self:IsShowingPercent() ) then
							local bval = math.floor( ((faction_barValue - faction_barMin) / (faction_barMax - faction_barMin)) * 100)
							tmpStanding = BossPanelUtils.Colorize(BossPanelUtils.COLOR_HEX_GREEN, faction_name)..":"..standingText.." ("..bval.."%)"
						else
							tmpStanding = BossPanelUtils.Colorize(BossPanelUtils.COLOR_HEX_GREEN, faction_name)..":"..standingText.." ("..faction_barValue - faction_barMin.."/"..faction_barMax - faction_barMin..")"	
						end
							
						info = {}
						info.text = tmpStanding
						info.value = tmpStanding
						
						info.func = function()
							self:SetMonitor()
						end
								
						info.checked = nil
						if ( info.text == self.data.monitor ) then
							info.checked = 1
						end
						UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL)
					else
						info = {}
						info.text = faction_name
						info.value = faction_name
						UIDropDownMenu_AddButton(info, UIDROPDOWNMENU_MENU_LEVEL)
					end
				end
			end
		end
		
		if ( UIDROPDOWNMENU_MENU_LEVEL == 1 ) then
			UIDropDownMenu_AddButton({
				text = self.loc.MENU_SHOW_AS_PERCENTAGE,
				func = function()
					self:ToggleShowingPercent()
				end,
				checked = self:IsShowingPercent(),
				keepShowOnClick = TRUE,
			})
			
			--UIDropDownMenu_AddButton({})
			BossPanelUtils.AddSpacerDropDownMenu()
			
			UIDropDownMenu_AddButton({
				text = self.loc.MENU_MONITOR,
				value = self.loc.MENU_MONITOR,
				hasArrow = 1,
			})
		end	
	end,
	
	UpdateTooltip = function(self)
		local NumFactions = GetNumFactions()

		local faction_name, faction_description, faction_standingID, faction_barMin, faction_barMax, faction_barValue, faction_atWarWith
		local faction_canToggleAtWar, faction_isHeader, faction_isCollapsed

		local factionIndex
		local standingText = ""
		
		for factionIndex=1, NumFactions do
			
			local tooltipRichText = ""
			
			faction_name, faction_description, faction_standingID, faction_barMin, faction_barMax, faction_barValue, faction_atWarWith, faction_canToggleAtWar, faction_isHeader, faction_isCollapsed = GetFactionInfo(factionIndex)
	
			if ( not faction_isHeader ) then
			
				standingText = self:FindRep(faction_standingID)
				
				if ( self:IsShowingPercent() ) then
					local bval = math.floor( ((faction_barValue - faction_barMin) / (faction_barMax - faction_barMin)) * 100)
					tooltipRichText = standingText.." ("..bval.."%)"
					BossPanelTooltip:AddDoubleLine(nil,faction_name..":", tooltipRichText, 0, 1, 0, 1, 1, 0)
				else
					tooltipRichText = standingText.." ("..faction_barValue - faction_barMin.."/"..faction_barMax - faction_barMin..")"
					BossPanelTooltip:AddDoubleLine(nil,faction_name..":", tooltipRichText, 0, 1, 0, 1, 1, 0)	
				end
			else
				BossPanelTooltip:AddLine(nil,faction_name, 1, 1, 1)
			end
		end
	end,
	
	UpdateText = function(self)
		if ( self.data.monitor ~= nil and self.data.monitor ~= "" ) then
			self:SetText(self.data.monitor)
		else
			self:SetText("Factions")
		end
	end,
	
	UpdateData = function(self)
		local NumFactions = GetNumFactions()

		local faction_name, faction_description, faction_standingID, faction_barMin, faction_barMax, faction_barValue, faction_atWarWith
		local faction_canToggleAtWar, faction_isHeader, faction_isCollapsed

		local factionIndex
		local standingText = ""
				
		for factionIndex=1, NumFactions do
			
			local tmpStanding = ""
			
			faction_name, faction_description, faction_standingID, faction_barMin, faction_barMax, faction_barValue, faction_atWarWith, faction_canToggleAtWar, faction_isHeader, faction_isCollapsed = GetFactionInfo(factionIndex)
		
			if ( not faction_isHeader ) then
					
							
				if ( self.data.monitor ~= nil and string.find(self.data.monitor, faction_name) ) then
				
					standingText = self:FindRep(faction_standingID)
					
					tmpStanding = BossPanelUtils.Colorize(BossPanelUtils.COLOR_HEX_GREEN, faction_name)..":"..standingText
					
					if ( self:IsShowingPercent() ) then
						local bval = math.floor( ((faction_barValue - faction_barMin) / (faction_barMax - faction_barMin)) * 100)
						tmpStanding = tmpStanding.." ("..bval.."%)"
					else
						tmpStanding = tmpStanding.." ("..faction_barValue - faction_barMin.."/"..faction_barMax - faction_barMin..")"	
					end
					
					self.data.monitor = tmpStanding
					self.charData.monitor = tmpStanding
					return
				end
			end
		end
	end,
	
	FindRep = function(self, standingID)
		local standingText = ""
		if ( standingID == 0 ) then
			standingText = UNKNOWN -- unknown
		elseif ( standingID == 1 ) then
			standingText = self.loc.FactionTextHated 	-- hated
		elseif ( standingID == 2) then
			standingText = self.loc.FactionTextHostile 	-- hostile
		elseif ( standingID == 3) then
			standingText = self.loc.FactionTextUnfriendly -- unfriendly
		elseif ( standingID == 4) then
			standingText = self.loc.FactionTextNeutral 	-- neutral
		elseif ( standingID == 5) then
			standingText = self.loc.FactionTextFriendly -- friendly
		elseif ( standingID == 6) then
			standingText = self.loc.FactionTextHonored 	-- honored
		elseif ( standingID == 7) then
			standingText = self.loc.FactionTextRevered 	-- revered
		elseif ( standingID == 8) then
			standingText = self.loc.FactionTextExalted 	-- exalted
		end
		return standingText
	end,
	
	IsShowingPercent = function(self)
		return self.data.showPercent
	end,
	
	ToggleShowingPercent = function(self, loud)
		self.data.showPercent = not self.data.showPercent
		if loud then
			self.cmd:status(self.loc.ARGUMENT_PERCENT, self.data.showPercent and 1 or 0, BossPanelLocals.MAP_ONOFF)
		end
		if ( self.data.monitor ~= "" ) then
			self:UpdateMonitor()
		end
		self:Update()
		return self.data.showPercent
	end,
	
	SetMonitor = function(self)
		if ( self.data.monitor == this.value ) then
			self.data.monitor = ""
			self.charData.monitor = ""
		else
			self.data.monitor = this.value
			self.charData.monitor = this.value
		end
		self:Update()
	end,
	
})

BossPanel_Factions:RegisterForLoad()